@@ -23,16 +23,28 @@
 #ifndef __PANGOFT2_H__
 #define __PANGOFT2_H__
 
-#include <pango/pango-layout.h>
+#include <fontconfig/fontconfig.h>
 
-#include <freetype/freetype.h>
+#include <pango/pango-layout.h>
+#include <pango/pangofc-font.h>
 
 G_BEGIN_DECLS
 
+#ifndef PANGO_DISABLE_DEPRECATED
 #define PANGO_RENDER_TYPE_FT2 "PangoRenderFT2"
+#endif
+
+#define PANGO_TYPE_FT2_FONT_MAP              (pango_ft2_font_map_get_type ())
+#define PANGO_FT2_FONT_MAP(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_FT2_FONT_MAP, PangoFT2FontMap))
+#define PANGO_FT2_IS_FONT_MAP(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_FT2_FONT_MAP))
+
+typedef struct _PangoFT2FontMap      PangoFT2FontMap;
+
+typedef void (*PangoFT2SubstituteFunc) (FcPattern *pattern,
+                                        gpointer   data);
 
 /* Calls for applications */
-PangoContext  *pango_ft2_get_context        (double dpi_x, double dpi_y);
+
 
 void           pango_ft2_render             (FT_Bitmap        *bitmap,
 					     PangoFont        *font,
@@ -48,18 +60,40 @@ void           pango_ft2_render_layout      (FT_Bitmap        *bitmap,
 					     int               x, 
 					     int               y);
 
-PangoFontMap      *pango_ft2_font_map_for_display    (void);
-void               pango_ft2_shutdown_display        (void);
+GType pango_ft2_font_map_get_type (void);
+
+PangoFontMap *pango_ft2_font_map_new                    (void);
+void          pango_ft2_font_map_set_resolution         (PangoFT2FontMap        *fontmap,
+							 double                  dpi_x,
+							 double                  dpi_y);
+void          pango_ft2_font_map_set_default_substitute (PangoFT2FontMap        *fontmap,
+							 PangoFT2SubstituteFunc  func,
+							 gpointer                data,
+							 GDestroyNotify          notify);
+void          pango_ft2_font_map_substitute_changed     (PangoFT2FontMap         *fontmap);
+PangoContext *pango_ft2_font_map_create_context         (PangoFT2FontMap         *fontmap);
+
 
 /* API for rendering modules
  */
+#ifndef PANGO_DISABLE_DEPRECATED
+PangoContext      *pango_ft2_get_context          (double dpi_x,
+						   double dpi_y);
+PangoFontMap      *pango_ft2_font_map_for_display (void);
+void               pango_ft2_shutdown_display     (void);
+
 PangoGlyph     pango_ft2_get_unknown_glyph (PangoFont       *font);
 int            pango_ft2_font_get_kerning  (PangoFont       *font,
 					    PangoGlyph       left,
 					    PangoGlyph       right);
-FT_Face        pango_ft2_font_get_face     (PangoFont       *font);
 PangoCoverage *pango_ft2_font_get_coverage (PangoFont       *font,
 					    PangoLanguage   *language);
+#endif /* PANGO_DISABLE_DEPRECATED */
+
+/* Temporarily undeprecated, will be deprecated in favour
+ * of pango_fc_font_lock_face() in 1.6
+ */
+FT_Face        pango_ft2_font_get_face     (PangoFont       *font);
 
 G_END_DECLS
 
